@@ -25,8 +25,7 @@ from typing import TYPE_CHECKING, Any
 
 from spython.main import Client
 
-from airflow.exceptions import AirflowException
-from airflow.providers.common.compat.sdk import BaseOperator
+from airflow.providers.common.compat.sdk import AirflowException, BaseOperator
 
 if TYPE_CHECKING:
     from airflow.providers.common.compat.sdk import Context
